/* 4.4BSD utility functions for error messages.
   Copyright (C) 1995,1996,1997,1998,1999,2003 Free Software Foundation, Inc.
   This file is part of the GNU C Library.

   The GNU C Library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either
   version 2.1 of the License, or (at your option) any later version.

   The GNU C Library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Lesser General Public License for more details.

   You should have received a copy of the GNU Lesser General Public
   License along with the GNU C Library; if not, write to the Free
   Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
   02111-1307 USA.  */

#ifndef	_ERR_H
#define	_ERR_H	1

#include <stdio.h>
#include <stdlib.h>
#include <stdarg.h>

#ifdef  __cplusplus
extern "C" {
#endif

#define VA(call) { \
	va_list ap; \
	va_start (ap, format); \
	call; \
	va_end (ap); \
}

static inline void vwarn (const char *format, __gnuc_va_list ap)
{
	flockfile (stderr);
	fprintf (stderr, "%s: ", __progname);
	if (format) {
		vfprintf (stderr, format, ap);
		fputs(": ", stderr);
	}
	fprintf (stderr, "%m\n");
	funlockfile (stderr);
}


static inline void vwarnx (const char *format, __gnuc_va_list ap)
{
	flockfile (stderr);
	fprintf (stderr, "%s: ", __progname);
	if (format)
		vfprintf (stderr, format, ap);
	putc_unlocked ('\n', stderr);
	funlockfile (stderr);
}

static inline void warnx (const char *format, ...)
{
	VA (vwarnx (format, ap))
}

static inline void warn (const char *format, ...)
{
	  VA (vwarn (format, ap))
}

static inline void verrx (int status, const char *format, __gnuc_va_list ap)
{
	vwarnx (format, ap);
	exit (status);
}

static inline void errx (int status, const char *format, ...)
{
	VA (verrx (status, format, ap))
}

static inline void verr (int status, const char *format, __gnuc_va_list ap)
{
	vwarn (format, ap);
	exit (status);
}

static inline void err (int status, const char *format, ...)
{
	VA (verr (status, format, ap))
}

#ifdef  __cplusplus
}
#endif

#endif	/* err.h */
